==> haskell-wai-handler-launch-3.0.2.4-94-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.4
id: wai-handler-launch-3.0.2.4-9XtpEImIyjHKVOAYCTgMra
key: wai-handler-launch-3.0.2.4-9XtpEImIyjHKVOAYCTgMra
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
abi: 9319b630cb4e1338c93ab736c86d91d7
exposed: True
exposed-modules:
    Network.Wai.Handler.Launch
import-dirs: /usr/lib/ghc-8.6.2/site-local/wai-handler-launch-3.0.2.4
library-dirs: /usr/lib/ghc-8.6.2/site-local/wai-handler-launch-3.0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/wai-handler-launch-3.0.2.4
hs-libraries: HSwai-handler-launch-3.0.2.4-9XtpEImIyjHKVOAYCTgMra
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 http-types-0.12.2-JL0Kcsx8GXu5DLLC6mrxVW
    process-1.6.3.0 streaming-commons-0.2.1.0-DDJaEcHSmGmAk0rq648nEd
    transformers-0.5.5.0 wai-3.2.1.2-BFXYuBVtQneLt4oXIwpyWq
    warp-3.2.25-SS2x5ocVoI31dLKz5kz13
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-handler-launch-3.0.2.4-105-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.4
id: wai-handler-launch-3.0.2.4-DdGTVLjTbQw3BPtcy09cGu
key: wai-handler-launch-3.0.2.4-DdGTVLjTbQw3BPtcy09cGu
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
abi: e300cb88c0bbc66f1ead22c30807b647
exposed: True
exposed-modules:
    Network.Wai.Handler.Launch
import-dirs: /usr/lib/ghc-8.6.3/site-local/wai-handler-launch-3.0.2.4
library-dirs: /usr/lib/ghc-8.6.3/site-local/wai-handler-launch-3.0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/wai-handler-launch-3.0.2.4
hs-libraries: HSwai-handler-launch-3.0.2.4-DdGTVLjTbQw3BPtcy09cGu
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 http-types-0.12.2-EPHxgevZtaq66NPaeVf0FD
    process-1.6.3.0 streaming-commons-0.2.1.0-98A77q62kI8Fyxj1zEbMgD
    transformers-0.5.5.0 wai-3.2.1.2-5o435cLCPoFEkqFQ2eloj
    warp-3.2.25-DaocYfaS4Y24BVlQNfZJ4T
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
